#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library
import json

# import interfaces
from pyams_utils.interfaces.data import IObjectData, IObjectDataRenderer
from pyams_utils.interfaces.tales import ITALESExtension
from pyramid.interfaces import IRequest
from zope.publisher.interfaces.browser import IBrowserRequest

# import packages
from pyams_utils.adapter import ContextAdapter, ContextRequestViewAdapter, adapter_config
from zope.interface import Interface


@adapter_config(context=IObjectData, provides=IObjectDataRenderer)
class ObjectDataRenderer(ContextAdapter):
    """Object data JSON renderer"""

    def get_object_data(self):
        data = IObjectData(self.context)
        return json.dumps(data.object_data) if data is not None else None


@adapter_config(name='object_data', context=(Interface, Interface, Interface), provides=ITALESExtension)
class ObjectDataExtension(ContextRequestViewAdapter):
    """extension:object_data TALES extension"""

    def render(self, context=None):
        if context is None:
            context = self.context
        renderer = IObjectDataRenderer(context, None)
        if renderer is not None:
            return renderer.get_object_data()


@adapter_config(name='request_data', context=(Interface, IRequest, Interface), provides=ITALESExtension)
class PyramidRequestDataExtension(ContextRequestViewAdapter):
    """extension:request_data TALES extension for Pyramid request"""

    def render(self, params=None):
        return self.request.annotations.get(params)


@adapter_config(name='request_data', context=(Interface, IBrowserRequest, Interface), provides=ITALESExtension)
class BrowserRequestDataExtension(ContextRequestViewAdapter):
    """extension:request_data TALES extension for Zope browser request"""

    def render(self, params=None):
        return self.request.annotations.get(params)
